from setuptools import setup,find_packages

setup(
  name="blues_util", # package name
  version="1.0.3", # package version
  long_description="blues util demo1",
  packages=find_packages(), # package module
  install_requires=[] # package dependency
)